@@ -168,8 +168,8 @@ ggplot_box <- function(data,
                        y_title = "[Y title]",
                        caption = "",
                        font_family = "Helvetica",
-                       font_size_title = 11,
-                       font_size_body = 10,
+                       font_size_title = NULL,
+                       font_size_body = NULL,
                        wrap_title = 70,
                        wrap_subtitle = 80,
                        wrap_x_title = 50,
@@ -188,6 +188,15 @@ ggplot_box <- function(data,
   if (is.numeric(x_var_vector)) stop("Please use a categorical x variable for a vertical boxplot")
   if (!is.numeric(y_var_vector)) stop("Please use a numeric y variable for a vertical boxplot")
   
+  if(is.null(font_size_title)){
+    if (isMobile == FALSE) font_size_title <- 11
+    else if (isMobile == TRUE) font_size_title <- 15
+  }
+  if(is.null(font_size_body)){
+    if (isMobile == FALSE) font_size_body <- 10
+    else if (isMobile == TRUE) font_size_body <- 14
+  }
+  
   if (is.null(pal)) pal <- pal_snz
   
   if (stat == "boxplot") {
@@ -322,7 +331,8 @@ ggplot_box <- function(data,
 #'   dplyr::mutate(price_thousands = (price / 1000)) %>%
 #'   dplyr::sample_frac(0.05)
 #'
-#' plot <- ggplot_box_facet(data = plot_data, x_var = cut, y_var = price_thousands, facet_var = color)
+#' plot <- ggplot_box_facet(data = plot_data, x_var = cut, y_var = price_thousands, facet_var = color,
+#'                          facet_nrow = 4)
 #'
 #' plot
 #'
@@ -344,8 +354,8 @@ ggplot_box_facet <-
            y_title = "[Y title]",
            caption = "",
            font_family = "Helvetica",
-           font_size_title = 11,
-           font_size_body = 10,
+           font_size_title = NULL,
+           font_size_body = NULL,
            wrap_title = 70,
            wrap_subtitle = 80,
            wrap_x_title = 50,
@@ -367,6 +377,15 @@ ggplot_box_facet <-
     if (!is.numeric(y_var_vector)) stop("Please use a numeric y variable for a vertical boxplot")
     if (is.numeric(facet_var_vector)) stop("Please use a categorical facet variable for a vertical boxplot")
     
+    if(is.null(font_size_title)){
+      if (isMobile == FALSE) font_size_title <- 11
+      else if (isMobile == TRUE) font_size_title <- 15
+    }
+    if(is.null(font_size_body)){
+      if (isMobile == FALSE) font_size_body <- 10
+      else if (isMobile == TRUE) font_size_body <- 14
+    }
+    
     if (is.null(pal)) pal <- pal_snz
     
     if (stat == "boxplot") {
