@@ -97,7 +97,7 @@ leaflet_stars <- function(data,
 #' @param data A stars object with dimensions x and y, and 1 attribute layer with crs in wgs84 (epsg4326). Required input.
 #' @param col_method The method of colouring features, either "bin", "quantile" or "category." Defaults to "quantile". Note all numeric variables are cut to be inclusive of the min in the range, and exclusive of the max in the range (except for the final bucket which includes the highest value).
 #' @param bin_cuts A vector of bin cuts applicable where col_method of "bin" is selected. The first number in the vector should be either -Inf or 0, and the final number Inf. If NULL, 'pretty' breaks are used. Only applicable where col_method equals "bin".
-#' @param quantile_cuts A vector of probability cuts applicable where col_method of "quantile" is selected. The first number in the vector should 0 and the final number 1. Defaults to 0-0.05, 0.05-0.25, 0.25-0.5, 0.5-0.75, 0.75-0.95, and 0.95-1. Only applicable where col_method equals "quantile".
+#' @param quantile_cuts A vector of probability cuts applicable where col_method of "quantile" is selected. The first number in the vector should 0 and the final number 1. Defaults to quartiles. Only applicable where col_method equals "quantile".
 #' @param pal Character vector of hex codes, or provided objects with pal_ prefixes. Defaults to viridis.
 #' @param rev_pal Reverses the palette. Defaults to F.
 #' @param opacity Sets the opacity of the grid cells. Defaults to 0.9.
@@ -110,11 +110,12 @@ leaflet_stars <- function(data,
 #' @return A leaflet object.
 #' @export
 #' @examples
-#' leaflet_stars_col(example_stars_nz_no3n,
+#' leaflet_stars_col(example_stars_nz_no3n, 
+#'    col_method = "quantile", quantile_cuts = c(0, 0.05, 0.25, 0.5, 0.75, 0.95, 1),
 #'    title = "River modelled median nitrate-nitrogen concentrations in g/m\u00b3, 2013\u201317")
 leaflet_stars_col <- function(data,
                               col_method = "quantile",
-                              quantile_cuts = c(0, 0.05, 0.25, 0.5, 0.75, 0.95, 1),
+                              quantile_cuts = c(0, 0.25, 0.5, 0.75, 1),
                               bin_cuts = NULL,
                               pal = NULL,
                               rev_pal = FALSE,
